@@ -6,7 +6,7 @@ use warnings;
 
 use base 'DateTime';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our (%strftime_patterns, %sub_format, @ORDINALS, @NTT);
 BEGIN {
@@ -250,23 +250,21 @@ sub _num2text {
 	my ($ns, $l, $o, @n2t) = ('', 3, ($_[1] ? -1 : 0), reverse(split('', $_[0])));
 	my $hundred = sub {
 		my ($string, $ord, @trip) = ('', @_, 0, 0, 0);
-		if (($trip[1] . $trip[0]) < 20) {
-			if (($trip[1] . $trip[0]) != 0) { $string = $NTT[0][$trip[1] . $trip[0]][$ord] };
-		} else {
+		if ($trip[1] > 1) {
 			for (0, 1) {
 				$string = sprintf(
 					"%s%s",
 					$NTT[$_][$trip[$_]][$string ? 0 : $ord],
 					($string ? '-' . $string : '')
-				) if ($trip[$_] != 0);
+				) if $trip[$_];
 			}
-		}
+		} elsif ($trip[0] || $trip[1]) { $string = $NTT[0][$trip[1] . $trip[0]][$ord]; }
 		$string = sprintf(
 			"%s %s%s",
 			$NTT[0][$trip[2]][0],
 			$NTT[2],
 			($string ? ' and ' . $string : ($ord != 0 ? 'th' : ''))
-		) if $trip[2] && $trip[2] != 0;
+		) if $trip[2];
 		return $string;
 	};
 	$ns = $hundred->($o, splice(@n2t, 0, 3));
@@ -302,7 +300,7 @@ DateTime::Ordinal - The great new DateTime::Ordinal!
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
